h-card parsing tests

# h-entry parsing tests ‐ change logs

The files in this directory where designed to test the parsing of mark-up which mixes version 1 and 2 microformats.

Theses are backwards compatibility tests for the older version 1 microformats specification. Please do not use this as a reference for authoring microformats.

## Change log:

- Updated JSON in order to reflect the parsing rules for src and alt attributes on img elements ‐ 24 June 2019 by Jan Sauer
- Created ‐ 7 June 2015 by Glenn Jones

## Contributors:

- Glenn Jones
- Jan Sauer